/*------------------------------------*
  Mobile Menu
*------------------------------------*/
#oceanwp-mobile-menu-icon {
  display: none;
  float: right;
  position: relative;
}

#oceanwp-mobile-menu-icon a {
  font-size: 13px;
  line-height: 74px;
  color: #555;
  padding-left: 15px;
  letter-spacing: 0.6px;
}

#oceanwp-mobile-menu-icon a:first-child {
  padding-left: 0;
}

#oceanwp-mobile-menu-icon a:hover {
  color: #13aff0;
}

#oceanwp-mobile-menu-icon a.mobile-menu i {
  padding-right: 6px;
}

/*------------------------------------*
  All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* boxed */
  .boxed-main-layout #wrap {
    overflow: hidden;
  }
  /* container */
  .container, body.content-full-screen .elementor-section.elementor-section-boxed > .elementor-container {
    max-width: 90%;
  }
  /* full width content and sidebar */
  .content-area,
  .content-left-sidebar .content-area {
    float: none;
    width: 100%;
    margin-bottom: 40px;
    padding: 0;
    border: 0;
  }
  .no-margins .content-area,
  .no-margins.content-left-sidebar .content-area {
    margin-bottom: 0;
  }
  .widget-area,
  .content-left-sidebar .widget-area {
    float: none;
    width: 100%;
    padding: 0;
    border: 0;
  }
  body.has-composer.has-sidebar #primary {
    margin-bottom: 40px;
  }
  #main #content-wrap.container {
    width: auto !important;
  }
  /* header > navbar */
  #oceanwp-mobile-menu-icon {
    display: block;
  }
  /* header > search overlay */
  #searchform-overlay {
    display: none !important;
  }
}

/*------------------------------------*
  Tablet Portrait
*------------------------------------*/
@media only screen and (min-width: 768px) and (max-width: 959px) {
  /* main  */
  body.boxed-main-layout #wrap {
    width: auto !important;
  }
  /* turn 4 column masonry grids into 2 columns */
  body .oceanwp-row .span_1_of_4.col-3.col,
  body .oceanwp-row .span_1_of_4.col.product:nth-child(2n+3) {
    margin-left: 0;
    clear: both;
  }
  body .oceanwp-row .span_1_of_4.col,
  body .oceanwp-isotope-grid .span_1_of_4.col {
    width: 50%;
  }
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  /* Visibility */
  .hide-tablet-mobile {
    display: none !important;
  }
  /* grid & main  */
  #wrap {
    width: 100% !important;
  }
  body.boxed-main-layout #wrap {
    width: auto !important;
  }
  .boxed-main-layout #top-bar-social.top-bar-right {
    right: auto;
  }
  .boxed-main-layout #top-bar-social.top-bar-left {
    left: auto;
  }
  .col {
    width: 100% !important;
    margin-bottom: 25px;
  }
}

/*------------------------------------*
  Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  /* Visibility */
  .hide-mobile {
    display: none !important;
  }
  /* boxed */
  .boxed-main-layout #wrap .container {
    padding-left: 20px;
    padding-right: 20px;
  }
  /* grid */
  .col {
    width: 100%;
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 30px;
  }
}

/*------------------------------------*
  Visibility
*------------------------------------*/
@media only screen and (min-width: 481px) and (max-width: 767px) {
  /* Visibility */
  .hide-tablet {
    display: none !important;
  }
}